## 周线行情

接口：weekly

描述：获取A股周线行情

限量：单次最大4500行，总量不限制

积分：用户需要至少2000积分才可以调取，具体请参阅积分获取办法

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | N | TS代码 （ts_code,trade_date两个参数任选一） |
| trade_date | str | N | 交易日期 （每周最后一个交易日期，YYYYMMDD格式） |
| start_date | str | N | 开始日期 |
| end_date | str | N | 结束日期 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | 股票代码 |
| trade_date | str | Y | 交易日期 |
| close | float | Y | 周收盘价 |
| open | float | Y | 周开盘价 |
| high | float | Y | 周最高价 |
| low | float | Y | 周最低价 |
| pre_close | float | Y | 上一周收盘价 |
| change | float | Y | 周涨跌额 |
| pct_chg | float | Y | 周涨跌幅 （未复权，如果是复权请用 通用行情接口 ） |
| vol | float | Y | 周成交量 |
| amount | float | Y | 周成交额 |

接口用法

```python
pro = ts.pro_api()

df = pro.weekly(ts_code='000001.SZ', start_date='20180101', end_date='20181101', fields='ts_code,trade_date,open,high,low,close,vol,amount')
```

或者

```python
df = pro.weekly(trade_date='20181123', fields='ts_code,trade_date,open,high,low,close,vol,amount')
```

数据样例

```python
ts_code   trade_date  close   open   high    low          vol  \
0   000001.SZ   20181026  11.18  10.81  11.46  10.71   9062500.14   
```